@@ -1486,68 +1486,6 @@ sub __supportsPostgreSQL {
 
 =pod
 
-=item * $class->__baseAsserts()
-
-Assert base-level inherited assertions for objects. These include: id,
-name, mtime, ctime.
-
-  __baseAsserts => sub($) {
-    my $class = shift;
-
-    my $base = $class->SUPER::__baseAsserts();
-
-    $base->{parentId} = Devel::Ladybug::Str->assert();
-
-    return Clone::clone( $base );
-  }
-
-=cut
-
-sub __baseAsserts {
-  my $class = shift;
-
-  my @dtArgs;
-
-  if ( $class->get("__useDbi") ) {
-    @dtArgs = ( columnType => $class->__datetimeColumnType() );
-  }
-
-  my $asserts = $class->get("__baseAsserts");
-
-  if ( !defined $asserts ) {
-    $asserts = Devel::Ladybug::Hash->new(
-      id => Devel::Ladybug::ID->assert(
-        Devel::Ladybug::Type::subtype(
-          descript => "The primary GUID key of this object"
-        )
-      ),
-      name => Devel::Ladybug::Name->assert(
-        Devel::Ladybug::Type::subtype(
-          descript => "A human-readable secondary key for this object",
-        )
-      ),
-      mtime => Devel::Ladybug::DateTime->assert(
-        Devel::Ladybug::Type::subtype(
-          descript => "The last modified timestamp of this object",
-          @dtArgs
-        )
-      ),
-      ctime => Devel::Ladybug::DateTime->assert(
-        Devel::Ladybug::Type::subtype(
-          descript => "The creation timestamp of this object",
-          @dtArgs
-        )
-      ),
-    );
-
-    $class->set( "__baseAsserts", $asserts );
-  }
-
-  return ( clone $asserts );
-}
-
-=pod
-
 =item * $class->__basePath()
 
 Return the base filesystem path used to store objects of the current
@@ -1613,7 +1551,7 @@ sub __primaryKey {
   my $key = $class->get("__primaryKey");
 
   if ( !defined $key ) {
-    $key = DefaultPrimaryKey;
+    $key = Devel::Ladybug::Persistence::DefaultPrimaryKey;
 
     $class->set( "__primaryKey", $key );
   }
@@ -1774,10 +1712,10 @@ sub __marshal {
   #
   # Re-assemble complex structures using data from linked tables.
   #
-  # For arrays, "elementIndex" is the array index, and "elementValue"
+  # For arrays, "name" is the array index, and "elementValue"
   # is the actual element value. Each element is a row in the linked table.
   #
-  # For hashes, "elementKey" is the key, and "elementValue" is the value.
+  # For hashes, "name" is the key, and "elementValue" is the value.
   # Each key/value pair is a row in the linked table.
   #
   # The parent object is referenced by id in parentId.
@@ -1851,7 +1789,7 @@ sub __marshal {
 
             $element = $elementClass->__marshal($element);
 
-            $hash->{ $element->elementKey() } = $element->elementValue();
+            $hash->{ $element->name() } = $element->elementValue();
           }
 
           $sth->finish();
@@ -2540,20 +2478,18 @@ sub __elementClass {
   my $elementClass;
 
   if ($type) {
-    my $base = $class->__baseAsserts();
-    delete $base->{name};
-
     if ( $type->objectClass()->isa('Devel::Ladybug::Array') ) {
       $elementClass = join( "::", $class, $key );
 
       create $elementClass => {
         __useDbi => $class->__useDbi,
 
-        name => Devel::Ladybug::Name->assert(
-          Devel::Ladybug::Type::subtype( optional => true )
+        name => Devel::Ladybug::Int->assert(
+          Devel::Ladybug::Type::subtype(
+            unique => "parentId"
+          )
         ),
         parentId     => $class->assert,
-        elementIndex => Devel::Ladybug::Int->assert,
         elementValue => $type->memberType,
       };
 
@@ -2565,11 +2501,12 @@ sub __elementClass {
       create $elementClass => {
         __useDbi => $class->__useDbi,
 
-        name => Devel::Ladybug::Name->assert(
-          Devel::Ladybug::Type::subtype( optional => true )
+        name => Devel::Ladybug::Str->assert(
+          Devel::Ladybug::Type::subtype(
+            unique => "parentId"
+          )
         ),
         parentId     => $class->assert,
-        elementKey   => Devel::Ladybug::Str->assert,
         elementValue => Devel::Ladybug::Str->assert,
       };
     }
@@ -3182,8 +3119,8 @@ sub _localSaveInsideTransaction {
 
           for my $value ( @{ $self->{$key} } ) {
             my $element = $elementClass->new(
+              name         => $i,
               parentId     => $self->key(),
-              elementIndex => $i,
               elementValue => $value,
             );
 
@@ -3198,8 +3135,8 @@ sub _localSaveInsideTransaction {
             my $value = $self->{$key}->{$elementKey};
 
             my $element = $elementClass->new(
+              name         => $elementKey,
               parentId     => $self->key(),
-              elementKey   => $elementKey,
               elementValue => $value,
             );
 
